@@ -25,6 +25,14 @@
 
 #include <errno.h>
 #include <net/if.h>
+#include <string.h>
+#include <sys/ioctl.h>
+#include <unistd.h>
+#include <stdio.h>
+
+#include <linux/if_vlan.h>
+#include <linux/sockios.h>
+#include <linux/ethtool.h>
 
 #ifndef IFF_LOWER_UP
 #define IFF_LOWER_UP	0x10000
@@ -50,6 +58,74 @@ struct ethernet_data {
 	struct connman_network *network;
 };
 
+
+static int get_vlan_vid(const char *ifname)
+{
+	struct vlan_ioctl_args vifr;
+	int vid;
+	int sk;
+
+	memset(&vifr, 0, sizeof(vifr));
+
+	sk = socket(AF_INET, SOCK_STREAM, 0);
+	if (sk < 0)
+		return -errno;
+
+	vifr.cmd = GET_VLAN_VID_CMD;
+	strncpy(vifr.device1, ifname, sizeof(vifr.device1));
+
+	if(ioctl(sk, SIOCSIFVLAN, &vifr) >= 0)
+		vid = vifr.u.VID;
+	else
+		vid = -errno;
+
+	close(sk);
+
+	return vid;
+}
+
+static int get_dsa_port(const char *ifname)
+{
+	int sk;
+	int dsaport = -1;
+	struct ifreq ifr;
+	struct ethtool_cmd cmd;
+	struct ethtool_drvinfo drvinfocmd;
+	struct vlan_ioctl_args vifr;
+
+	sk = socket(AF_INET, SOCK_STREAM, 0);
+	if (sk < 0)
+		return -errno;
+
+	memset(&ifr, 0, sizeof(ifr));
+	strncpy(ifr.ifr_name, ifname, sizeof(ifr.ifr_name));
+
+	/* check if it is a vlan and get physical interface name*/
+	vifr.cmd = GET_VLAN_REALDEV_NAME_CMD;
+	strncpy(vifr.device1, ifname, sizeof(vifr.device1));
+
+	if(ioctl(sk, SIOCSIFVLAN, &vifr) >= 0)
+		strncpy(ifr.ifr_name, vifr.u.device2, sizeof(ifr.ifr_name));
+
+	/* get driver info */
+	drvinfocmd.cmd =  ETHTOOL_GDRVINFO;
+	ifr.ifr_data = (caddr_t)&drvinfocmd;
+
+	if (!ioctl(sk, SIOCETHTOOL, &ifr)) {
+		if(!strcmp(drvinfocmd.driver, "dsa")) {
+			/* get dsa port*/
+			cmd.cmd =  ETHTOOL_GSET;
+			ifr.ifr_data = (caddr_t)&cmd;
+
+			if (!ioctl(sk, SIOCETHTOOL, &ifr))
+				dsaport = cmd.phy_address;
+		}
+	}
+	close(sk);
+
+	return dsaport;
+}
+
 static int eth_network_probe(struct connman_network *network)
 {
 	DBG("network %p", network);
@@ -94,6 +170,7 @@ static void add_network(struct connman_device *device,
 {
 	struct connman_network *network;
 	int index;
+	char *ifname;
 
 	network = connman_network_create("carrier",
 					CONNMAN_NETWORK_TYPE_ETHERNET);
@@ -102,6 +179,9 @@ static void add_network(struct connman_device *device,
 
 	index = connman_device_get_index(device);
 	connman_network_set_index(network, index);
+	ifname = connman_inet_ifname(index);
+	if (!ifname)
+		return;
 
 	connman_network_set_name(network, "Wired");
 
@@ -110,15 +190,30 @@ static void add_network(struct connman_device *device,
 		return;
 	}
 
-	if (!eth_tethering)
+	if (!eth_tethering) {
+		char group[16] = "cable";
+		int vid, dsaport;
+
+		vid = get_vlan_vid(ifname);
+		dsaport = get_dsa_port(ifname);
+
 		/*
 		 * Prevent service from starting the reconnect
 		 * procedure as we do not want the DHCP client
 		 * to run when tethering.
 		 */
-		connman_network_set_group(network, "cable");
+		if((vid >= 0) && (dsaport >= 0))
+			snprintf(group, sizeof(group), "p%02x_%03x_cable", dsaport, vid);
+		else if (vid >= 0)
+			snprintf(group, sizeof(group), "%03x_cable", vid);
+		else if (dsaport >= 0)
+			snprintf(group, sizeof(group), "p%02x_cable", dsaport);
+
+		connman_network_set_group(network, group);
+	}
 
 	ethernet->network = network;
+	g_free(ifname);
 }
 
 static void remove_network(struct connman_device *device,
