@@ -143,6 +143,8 @@ struct network_context {
 	struct connman_ipaddress *ipv6_address;
 	char *ipv6_nameservers;
 
+	int refcount;
+
 	bool active;
 	bool valid_apn; /* APN is 'valid' if length > 0 */
 };
@@ -271,11 +273,25 @@ static struct network_context *network_context_alloc(const char *path)
 	context->ipv6_address = NULL;
 	context->ipv6_nameservers = NULL;
 
+	context->refcount = 1;
+
 	return context;
 }
 
-static void network_context_free(struct network_context *context)
+static void network_context_ref(struct network_context *context)
 {
+	DBG("%p ref %d", context, context->refcount + 1);
+
+	__sync_fetch_and_add(&context->refcount, 1);
+}
+
+static void network_context_unref(struct network_context *context)
+{
+	DBG("%p ref %d", context, context->refcount - 1);
+
+	if (__sync_fetch_and_sub(&context->refcount, 1) != 1)
+		return;
+
 	g_free(context->path);
 
 	connman_ipaddress_free(context->ipv4_address);
@@ -389,6 +405,16 @@ struct property_info {
 	get_properties_cb get_properties_cb;
 };
 
+static void free_property_info(void * memory)
+{
+	struct property_info * info = memory;
+
+	if (info->context)
+		network_context_unref(info->context);
+
+	g_free(info);
+}
+
 static void set_property_reply(DBusPendingCall *call, void *user_data)
 {
 	struct property_info *info = user_data;
@@ -476,8 +502,11 @@ static int set_property(struct modem_data *modem,
 	info->property = property;
 	info->set_property_cb = notify;
 
+	if (info->context)
+		network_context_ref(info->context);
+
 	dbus_pending_call_set_notify(modem->call_set_property,
-					set_property_reply, info, g_free);
+				set_property_reply, info, free_property_info);
 
 	dbus_message_unref(message);
 
@@ -812,7 +841,6 @@ static void extract_ipv4_settings(DBusMessageIter *array,
 
 	connman_ipaddress_free(context->ipv4_address);
 	context->ipv4_address = NULL;
-	context->index = -1;
 
 	if (dbus_message_iter_get_arg_type(array) != DBUS_TYPE_ARRAY)
 		return;
@@ -915,7 +943,6 @@ static void extract_ipv6_settings(DBusMessageIter *array,
 
 	connman_ipaddress_free(context->ipv6_address);
 	context->ipv6_address = NULL;
-	context->index = -1;
 
 	if (dbus_message_iter_get_arg_type(array) != DBUS_TYPE_ARRAY)
 		return;
@@ -1228,7 +1255,7 @@ static int add_cm_context(struct modem_data *modem, const char *context_path,
 	}
 
 	if (g_strcmp0(context_type, "internet") != 0) {
-		network_context_free(context);
+		network_context_unref(context);
 		return -EINVAL;
 	}
 
@@ -1261,7 +1288,7 @@ static void remove_cm_context(struct modem_data *modem,
 		remove_network(modem, context);
 	modem->context_list = g_slist_remove(modem->context_list, context);
 
-	network_context_free(context);
+	network_context_unref(context);
 	context = NULL;
 }
 
@@ -1801,7 +1828,8 @@ static void add_cdma_network(struct modem_data *modem)
 		context = network_context_alloc(modem->path);
 		modem->context_list = g_slist_prepend(modem->context_list,
 							context);
-	}
+	} else
+		context = modem->context_list->data;
 
 	if (!modem->name)
 		modem->name = g_strdup("CDMA Network");
@@ -2470,16 +2498,19 @@ static void remove_modem(gpointer data)
 	if (modem->call_set_property) {
 		dbus_pending_call_cancel(modem->call_set_property);
 		dbus_pending_call_unref(modem->call_set_property);
+		modem->call_set_property = NULL;
 	}
 
 	if (modem->call_get_properties) {
 		dbus_pending_call_cancel(modem->call_get_properties);
 		dbus_pending_call_unref(modem->call_get_properties);
+		modem->call_get_properties = NULL;
 	}
 
 	if (modem->call_get_contexts) {
 		dbus_pending_call_cancel(modem->call_get_contexts);
 		dbus_pending_call_unref(modem->call_get_contexts);
+		modem->call_get_contexts = NULL;
 	}
 
 	/* Must remove the contexts before the device */
@@ -2669,6 +2700,9 @@ static int network_connect(struct connman_network *network)
 
 	DBG("%s network %p", modem->path, network);
 
+	if (!g_hash_table_lookup(modem_hash, modem->path))
+		return -ENODEV;
+
 	context = get_context_with_network(modem->context_list, network);
 	if (!context)
 		return -ENODEV;
@@ -2690,6 +2724,9 @@ static int network_disconnect(struct connman_network *network)
 
 	DBG("%s network %p", modem->path, network);
 
+	if (!g_hash_table_lookup(modem_hash, modem->path))
+		return -ENODEV;
+
 	context = get_context_with_network(modem->context_list, network);
 	if (!context)
 		return -ENODEV;
