@@ -399,8 +399,10 @@ static void free_ipdevice(gpointer data)
 
 	g_free(ipdevice->address);
 
-	set_ipv6_state(ifname, ipdevice->ipv6_enabled);
-	set_ipv6_privacy(ifname, ipdevice->ipv6_privacy);
+	if (ifname) {
+		set_ipv6_state(ifname, ipdevice->ipv6_enabled);
+		set_ipv6_privacy(ifname, ipdevice->ipv6_privacy);
+	}
 
 	g_free(ifname);
 	g_free(ipdevice);
@@ -1104,8 +1106,6 @@ static struct connman_ipconfig *create_ipv6config(int index)
 	struct connman_ipconfig *ipv6config;
 	struct connman_ipdevice *ipdevice;
 
-	DBG("index %d", index);
-
 	ipv6config = g_try_new0(struct connman_ipconfig, 1);
 	if (!ipv6config)
 		return NULL;
@@ -1132,7 +1132,7 @@ static struct connman_ipconfig *create_ipv6config(int index)
 
 	ipv6config->system = connman_ipaddress_alloc(AF_INET6);
 
-	DBG("ipconfig %p method %s", ipv6config,
+	DBG("ipconfig %p index %d method %s", ipv6config, index,
 		__connman_ipconfig_method2string(ipv6config->method));
 
 	return ipv6config;
@@ -1153,8 +1153,6 @@ struct connman_ipconfig *__connman_ipconfig_create(int index,
 	if (type == CONNMAN_IPCONFIG_TYPE_IPV6)
 		return create_ipv6config(index);
 
-	DBG("index %d", index);
-
 	ipconfig = g_try_new0(struct connman_ipconfig, 1);
 	if (!ipconfig)
 		return NULL;
@@ -1172,7 +1170,7 @@ struct connman_ipconfig *__connman_ipconfig_create(int index,
 
 	ipconfig->system = connman_ipaddress_alloc(AF_INET);
 
-	DBG("ipconfig %p", ipconfig);
+	DBG("ipconfig %p index %d", ipconfig, index);
 
 	return ipconfig;
 }
@@ -1305,8 +1303,6 @@ enum connman_ipconfig_method __connman_ipconfig_get_method(
 
 int __connman_ipconfig_address_add(struct connman_ipconfig *ipconfig)
 {
-	DBG("");
-
 	switch (ipconfig->method) {
 	case CONNMAN_IPCONFIG_METHOD_UNKNOWN:
 	case CONNMAN_IPCONFIG_METHOD_OFF:
@@ -1330,13 +1326,9 @@ int __connman_ipconfig_address_remove(struct connman_ipconfig *ipconfig)
 {
 	int err;
 
-	DBG("");
-
 	if (!ipconfig)
 		return 0;
 
-	DBG("method %d", ipconfig->method);
-
 	switch (ipconfig->method) {
 	case CONNMAN_IPCONFIG_METHOD_UNKNOWN:
 	case CONNMAN_IPCONFIG_METHOD_OFF:
@@ -1358,13 +1350,9 @@ int __connman_ipconfig_address_unset(struct connman_ipconfig *ipconfig)
 {
 	int err;
 
-	DBG("");
-
 	if (!ipconfig)
 		return 0;
 
-	DBG("method %d", ipconfig->method);
-
 	switch (ipconfig->method) {
 	case CONNMAN_IPCONFIG_METHOD_UNKNOWN:
 	case CONNMAN_IPCONFIG_METHOD_OFF:
@@ -1395,8 +1383,6 @@ int __connman_ipconfig_set_proxy_autoconfig(struct connman_ipconfig *ipconfig,
 {
 	struct connman_ipdevice *ipdevice;
 
-	DBG("ipconfig %p", ipconfig);
-
 	if (!ipconfig || ipconfig->index < 0)
 		return -ENODEV;
 
@@ -1415,8 +1401,6 @@ const char *__connman_ipconfig_get_proxy_autoconfig(struct connman_ipconfig *ipc
 {
 	struct connman_ipdevice *ipdevice;
 
-	DBG("ipconfig %p", ipconfig);
-
 	if (!ipconfig || ipconfig->index < 0)
 		return NULL;
 
@@ -1751,8 +1735,6 @@ int __connman_ipconfig_ipv6_set_privacy(struct connman_ipconfig *ipconfig,
 	if (!ipconfig)
 		return -EINVAL;
 
-	DBG("ipconfig %p privacy %s", ipconfig, value);
-
 	privacy = string2privacy(value);
 
 	ipconfig->ipv6_privacy_config = privacy;
@@ -1768,8 +1750,6 @@ void __connman_ipconfig_append_ipv4(struct connman_ipconfig *ipconfig,
 	struct connman_ipaddress *append_addr = NULL;
 	const char *str;
 
-	DBG("");
-
 	if (ipconfig->type != CONNMAN_IPCONFIG_TYPE_IPV4)
 		return;
 
@@ -1782,13 +1762,13 @@ void __connman_ipconfig_append_ipv4(struct connman_ipconfig *ipconfig,
 	switch (ipconfig->method) {
 	case CONNMAN_IPCONFIG_METHOD_UNKNOWN:
 	case CONNMAN_IPCONFIG_METHOD_OFF:
-	case CONNMAN_IPCONFIG_METHOD_AUTO:
 		return;
 
 	case CONNMAN_IPCONFIG_METHOD_FIXED:
 		append_addr = ipconfig->address;
 		break;
 
+	case CONNMAN_IPCONFIG_METHOD_AUTO:
 	case CONNMAN_IPCONFIG_METHOD_MANUAL:
 	case CONNMAN_IPCONFIG_METHOD_DHCP:
 		append_addr = ipconfig->system;
@@ -1825,8 +1805,6 @@ void __connman_ipconfig_append_ipv6(struct connman_ipconfig *ipconfig,
 	struct connman_ipaddress *append_addr = NULL;
 	const char *str, *privacy;
 
-	DBG("");
-
 	if (ipconfig->type != CONNMAN_IPCONFIG_TYPE_IPV6)
 		return;
 
@@ -1883,8 +1861,6 @@ void __connman_ipconfig_append_ipv6config(struct connman_ipconfig *ipconfig,
 {
 	const char *str, *privacy;
 
-	DBG("");
-
 	str = __connman_ipconfig_method2string(ipconfig->method);
 	if (!str)
 		return;
@@ -1927,8 +1903,6 @@ void __connman_ipconfig_append_ipv4config(struct connman_ipconfig *ipconfig,
 {
 	const char *str;
 
-	DBG("");
-
 	str = __connman_ipconfig_method2string(ipconfig->method);
 	if (!str)
 		return;
@@ -1979,8 +1953,6 @@ int __connman_ipconfig_set_config(struct connman_ipconfig *ipconfig,
 	DBusMessageIter dict;
 	int type = -1;
 
-	DBG("ipconfig %p", ipconfig);
-
 	if (dbus_message_iter_get_arg_type(array) != DBUS_TYPE_ARRAY)
 		return -EINVAL;
 
@@ -2250,6 +2222,20 @@ int __connman_ipconfig_load(struct connman_ipconfig *ipconfig,
 		g_free(key);
 		break;
 
+	case CONNMAN_IPCONFIG_METHOD_AUTO:
+
+		if (ipconfig->type != CONNMAN_IPCONFIG_TYPE_IPV4)
+			break;
+
+		/*
+		 * If the last used method for IPv4 was AUTO then we
+		 * try first DHCP. We will try also to use the last
+		 * used DHCP address, if exits.
+		 */
+		__connman_ipconfig_set_method(ipconfig,
+					CONNMAN_IPCONFIG_METHOD_DHCP);
+		/* fall through */
+
 	case CONNMAN_IPCONFIG_METHOD_DHCP:
 
 		key = g_strdup_printf("%sDHCP.LastAddress", prefix);
@@ -2261,9 +2247,6 @@ int __connman_ipconfig_load(struct connman_ipconfig *ipconfig,
 		g_free(key);
 
 		break;
-
-	case CONNMAN_IPCONFIG_METHOD_AUTO:
-		break;
 	}
 
 	return 0;
@@ -2363,6 +2346,8 @@ int __connman_ipconfig_save(struct connman_ipconfig *ipconfig,
 	if (ipconfig->address->gateway)
 		g_key_file_set_string(keyfile, identifier,
 			key, ipconfig->address->gateway);
+	else
+		g_key_file_remove_key(keyfile, identifier, key, NULL);
 	g_free(key);
 
 	return 0;
